# coding: utf-8

"""
    Mux API

    Mux is how developers build online video. This API encompasses both Mux Video and Mux Data functionality to help you build your video-related projects better and faster than ever before.  # noqa: E501

    The version of the OpenAPI document: v1
    Contact: devex@mux.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mux_python
from mux_python.api.playback_restrictions_api import PlaybackRestrictionsApi  # noqa: E501
from mux_python.rest import ApiException


class TestPlaybackRestrictionsApi(unittest.TestCase):
    """PlaybackRestrictionsApi unit test stubs"""

    def setUp(self):
        self.api = mux_python.api.playback_restrictions_api.PlaybackRestrictionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_playback_restriction(self):
        """Test case for create_playback_restriction

        Create a Playback Restriction  # noqa: E501
        """
        pass

    def test_delete_playback_restriction(self):
        """Test case for delete_playback_restriction

        Delete a Playback Restriction  # noqa: E501
        """
        pass

    def test_get_playback_restriction(self):
        """Test case for get_playback_restriction

        Retrieve a Playback Restriction  # noqa: E501
        """
        pass

    def test_list_playback_restrictions(self):
        """Test case for list_playback_restrictions

        List Playback Restrictions  # noqa: E501
        """
        pass

    def test_update_referrer_domain_restriction(self):
        """Test case for update_referrer_domain_restriction

        Update the Referrer Playback Restriction  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
